import re


class CommandError(Exception):
    pass


class BaseCommand():
    """
    Base command, this will accept and handle some generic features of all commands.
    Like error handling, argument retrieving / checking
    """

    def __init__(self, args):
        """
        Initialize the class
        """
        self._args = args

    def arg(self, key):
        """
        Retrieve a single argument
        """
        return self._args.get(key)

    def args(self, *keys):
        """
        Retrieve a set of argument
        """
        if keys:
            return [self.arg(k) for k in keys]
        else:
            return self._args

    def value(self, key):
        """
        Retrieve a single argument
        """
        key = '<{0}>'.format(key)
        return self.arg(key)

    def option(self, key, value=None):
        """
        Retrieve a single argument
        """
        key = '--'+key

        if value:
            return self.arg(key) == value

        return self.arg(key)

    def args_context(self):
        """
        Convert all options and values into a context usable by the template parser
        """
        context = dict(options={}, values={})
        for key, value in self.args().items():

            expressions = {
                'options': r'--(.*)',
                'values': r'<(.*)>',
            }

            for group, expression in expressions.items():
                matches = re.search(expression, key)
                if matches:
                    context[matches.group(1).replace('-', '_')] = value

        return context