"""Snelis commandline tool.

Usage:
    snelis create project <path> [options] [-e <extensions>...]
    snelis create app <path> [options]

Options:
    -h --help                       Show this screen.
    --version                       Show version.

    -v <verbosity>, --verbose=<verbosity>
                                    Verbosity level; 0=minimal output, 1=normal output,
                                    2=verbose output, 3=very verbose output [default: 0]

Django options:
    --template=<location>           Use an alternative django template to setup the app or project
    --main-app=<location>           The name of the primary django app [default: main]
    -e <extensions> --extensions    The extensions django needs to process [default: py md]

Virtualenv options:
    --no-virtualenv                 Skip the virtualenv creation
    --venv-name=<file>              Virtualenv name [default: venv]

Vagrant options
    --no-vagrant                    Skip Vagrant file creation
    --box-name=<name>               Vagrant box name [default: lucid64]
    --box-url=<url>                 Vagrant box url [default: http://files.vagrantup.com/precise64.box]

Puppet options:
    --puppet                    Include Puppet

"""
import sys
from docopt import docopt
from utils import load_command, find_commands


def run():
    argv = None
    if len(sys.argv) < 2:
        argv = ['create', 'project', '/Users/niels/Sites/test/ngnix-uwsgi-django/henk']

    args = docopt(__doc__, argv=argv, version='Snelis {0}'.format('0.1.0'))

    if args['--verbose']:
        print args

    for command in find_commands():
        if args[command]:
            load_command('project', args=args).handle()


# If this is being executed directly, execute the runner
if __name__ == '__main__':
    run()