from importlib import import_module

from random import choice

import shutil
from django.template import Template
import os
import re
import stat


def find_commands(management_dir=None):
    """
    Given a path to a management directory, returns a list of all the command
    names that are available.

    Returns an empty list if no commands are defined.
    """

    if not management_dir:
        management_dir = os.path.dirname(__file__)

    command_dir = os.path.join(management_dir, 'commands')
    try:
        return [f[:-3] for f in os.listdir(command_dir)
                if not f.startswith('_') and f.endswith('.py')]
    except OSError:
        return []


def load_command(name, *args, **kwargs):
    """
    Given a command name and an application name, returns the Command
    class instance. All errors raised by the import process
    (ImportError, AttributeError) are allowed to propagate.
    """
    module = import_module('snelis.management.commands.{0}'.format(name))
    return module.Command(*args, **kwargs)


# def copy_template(src, dest, context={}):
#     """
#     Copy all files in the source path to the destination path.
#
#     To replace boilerplate strings in the source data, pass a dictionary to the
#     ``replace`` argument where each key is the boilerplate string and the
#     corresponding value is the string which should replace it.
#
#     The destination file paths are also parsed through the boilerplate
#     replacements, so directories and file names may also be modified.
#
#     """
#     for path, dirs, files in os.walk(src):
#         relative_path = path[len(src):].lstrip(os.sep)
#         # Replace boilerplate strings in destination directory.
#
#         replaces = {}
#         for d in context.values():
#             replaces.update(d)
#
#         for old_val, new_val in replaces.items():
#             relative_path = relative_path.replace(old_val, new_val)
#
#         os.mkdir(os.path.join(dest, relative_path))
#
#         for i, subdir in enumerate(dirs):
#             if subdir.startswith('.'):
#                 del dirs[i]
#
#         for filename in files:
#             if (filename.startswith('.startproject') or filename.endswith('.pyc')):
#                 continue
#
#             src_file_path = os.path.join(path, filename)
#             # Replace boilerplate strings in destination filename.
#             for old_val, new_val in replaces.items():
#                 filename = filename.replace(old_val, new_val)
#
#             dest_file_path = os.path.join(dest, relative_path, filename)
#             copy_template_file(src_file_path, dest_file_path, context)
#
#
# def copy_template_file(src, dest, context={}):
#     """
#     Copy a source file to a new destination file.
#
#     To replace boilerplate strings in the source data, pass a dictionary to the
#     ``replace`` argument where each key is the boilerplate string and the
#     corresponding value is the string which should replace it.
#
#     """
#
#     # Generate SECRET_KEY for settings file
#     secret_key = ''.join([choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)])
#     context.setdefault(secret_key, secret_key)
#
#     # Read the data from the source file.
#     with open(src, 'rb') as template_file:
#         content = template_file.read()
#         content = content.decode('utf-8')
#         template = Template(content)
#         content = template.render(context)
#         content = content.encode('utf-8')
#     with open(dest, 'wb') as dest_file:
#         dest_file.write(content)
#
#     # Copy permissions from source file.
#     shutil.copymode(src, dest)
#
#     # Make new file writable.
#     if os.access(dest, os.W_OK):
#         st = os.stat(dest)
#         new_permissions = stat.S_IMODE(st.st_mode) | stat.S_IWUSR
#         os.chmod(dest, new_permissions)
#
#
# def get_boilerplate(path, project_name):
#     """
#     Look for a ``.startproject_boilerplate`` file the given path and parse it.
#
#     Return a list of 3-part tuples, each containing a boilerplate variable,
#     optional description and default value.
#
#     If no file was found (or no lines contained boilerplate variables), return
#     an empty list.
#
#     """
#     defaults = {}
#     defaults_path = os.path.join(path, '.startproject_defaults')
#     if os.path.isfile(defaults_path):
#         defaults_file = open(defaults_path, 'r')
#         for line in defaults_file:
#             match = re.match(r'\s*(\w+)\s*(.*)$', line)
#             if match:
#                 var, default = match.groups()
#                 defaults[var] = default
#     boilerplate = []
#     boilerplate_path = os.path.join(path, '.startproject_boilerplate')
#     if os.path.isfile(boilerplate_path):
#         boilerplate_file = open(boilerplate_path, 'r')
#         for line in boilerplate_file:
#             match = re.match(r'\s*(\w+)\s*(.*)$', line)
#             if match:
#                 var, description = match.groups()
#                 default = defaults.get(var)
#                 boilerplate.append((var, description, default))
#     return boilerplate